summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneytransaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneytransaction.h')
-rw-r--r--kmymoney2/mymoney/mymoneytransaction.h84
1 files changed, 42 insertions, 42 deletions
diff --git a/kmymoney2/mymoney/mymoneytransaction.h b/kmymoney2/mymoney/mymoneytransaction.h
index ce52779..21c28ea 100644
--- a/kmymoney2/mymoney/mymoneytransaction.h
+++ b/kmymoney2/mymoney/mymoneytransaction.h
@@ -26,10 +26,10 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstring.h>
-#include <qdatetime.h>
-#include <qptrlist.h>
-#include <qstringlist.h>
+#include <tqstring.h>
+#include <tqdatetime.h>
+#include <tqptrlist.h>
+#include <tqstringlist.h>
// ----------------------------------------------------------------------------
// Project Includes
@@ -43,7 +43,7 @@
/**
* This class represents a transaction within the MyMoneyEngine. A transaction
* contains none, one or more splits of type MyMoneySplit. They are stored in
* a QValueList<MyMoneySplit> within this object. A transaction containing only
* a single split with an amount not equal to 0 is an unbalanced transaction. It
* is tolerated by the engine, but in general not a good idea as it is financially
* wrong.
@@ -52,35 +52,35 @@ class KMYMONEY_EXPORT MyMoneyTransaction : public MyMoneyObject, public MyMoneyK
{
public:
MyMoneyTransaction();
- MyMoneyTransaction(const QString id,
+ MyMoneyTransaction(const TQString id,
const MyMoneyTransaction& transaction);
/**
* @param node reference to QDomNode
* @param forceId see MyMoneyObject(const QDomElement&, const bool)
*/
- MyMoneyTransaction(const QDomElement& node, const bool forceId = true);
+ MyMoneyTransaction(const TQDomElement& node, const bool forceId = true);
~MyMoneyTransaction();
public:
- friend QDataStream &operator<<(QDataStream &, MyMoneyTransaction &);
- friend QDataStream &operator>>(QDataStream &, MyMoneyTransaction &);
+ friend TQDataStream &operator<<(TQDataStream &, MyMoneyTransaction &);
+ friend TQDataStream &operator>>(TQDataStream &, MyMoneyTransaction &);
// Simple get operations
- const QDate& entryDate(void) const { return m_entryDate; };
- const QDate& postDate(void) const { return m_postDate; };
- const QString& memo(void) const { return m_memo; };
- const QValueList<MyMoneySplit>& splits(void) const { return m_splits; };
- QValueList<MyMoneySplit>& splits(void) { return m_splits; };
+ const TQDate& entryDate(void) const { return m_entryDate; };
+ const TQDate& postDate(void) const { return m_postDate; };
+ const TQString& memo(void) const { return m_memo; };
+ const TQValueList<MyMoneySplit>& splits(void) const { return m_splits; };
+ TQValueList<MyMoneySplit>& splits(void) { return m_splits; };
unsigned int splitCount(void) const { return m_splits.count(); };
- const QString& commodity(void) const { return m_commodity; };
- const QString& bankID(void) const /*__attribute__ ((deprecated))*/ { return m_bankID; };
+ const TQString& commodity(void) const { return m_commodity; };
+ const TQString& bankID(void) const /*__attribute__ ((deprecated))*/ { return m_bankID; };
// Simple set operations
- void setPostDate(const QDate& date);
- void setEntryDate(const QDate& date);
- void setMemo(const QString& memo);
- void setCommodity(const QString& commodityId) { m_commodity = commodityId; };
- void setBankID(const QString& bankID) /*__attribute__ ((deprecated))*/ { m_bankID = bankID; };
+ void setPostDate(const TQDate& date);
+ void setEntryDate(const TQDate& date);
+ void setMemo(const TQString& memo);
+ void setCommodity(const TQString& commodityId) { m_commodity = commodityId; };
+ void setBankID(const TQString& bankID) /*__attribute__ ((deprecated))*/ { m_bankID = bankID; };
bool operator == (const MyMoneyTransaction&) const;
inline bool operator != (const MyMoneyTransaction& r) const { return !(*this == r); };
@@ -100,7 +100,7 @@ public:
*
* @return reference to split within the transaction is returned
*/
- const MyMoneySplit& splitByAccount(const QString& accountId, const bool match = true) const;
+ const MyMoneySplit& splitByAccount(const TQString& accountId, const bool match = true) const;
/**
* This method is essentially the same as the previous method, except that
@@ -112,7 +112,7 @@ public:
*
* @return reference to split within the transaction is returned
*/
- const MyMoneySplit& splitByAccount(const QStringList& accountIds, const bool match = true) const;
+ const MyMoneySplit& splitByAccount(const TQStringList& accountIds, const bool match = true) const;
/**
* This method is used to extract a split from a transaction.
@@ -121,7 +121,7 @@ public:
*
* @return reference to split within the transaction is returned
*/
- const MyMoneySplit& splitById(const QString& splitId) const;
+ const MyMoneySplit& splitById(const TQString& splitId) const;
/**
* This method is used to extract a split for a given payeeId
@@ -131,7 +131,7 @@ public:
*
* @return reference to split within the transaction is returned
*/
- const MyMoneySplit& splitByPayee(const QString& payeeId) const;
+ const MyMoneySplit& splitByPayee(const TQString& payeeId) const;
/**
* This method is used to check if the given account is used
@@ -139,7 +139,7 @@ public:
*
* @param id account id that should be checked for usage
*/
- bool accountReferenced(const QString& id) const;
+ bool accountReferenced(const TQString& id) const;
/**
* This method is used to add a split to the transaction. The split
@@ -237,11 +237,11 @@ public:
* out the split that references the account through which a transaction
* was entered.
*
* @return QString with ID of the first split of transactions
*/
- static const QString firstSplitID(void);
+ static const TQString firstSplitID(void);
- void writeXML(QDomDocument& document, QDomElement& parent) const;
+ void writeXML(TQDomDocument& document, TQDomElement& tqparent) const;
/**
* This method checks if a reference to the given object exists. It returns,
@@ -252,7 +252,7 @@ public:
* @retval true This object references object with id @p id.
* @retval false This object does not reference the object with id @p id.
*/
- virtual bool hasReferenceTo(const QString& id) const;
+ virtual bool hasReferenceTo(const TQString& id) const;
/**
* Checks whether any split contains an autocalc split.
@@ -277,9 +277,9 @@ public:
* the number of splits referencing this account. The default for
* this parameter is @p false.
*/
- QString accountSignature(bool includeSplitCount = false) const;
+ TQString accountSignature(bool includeSplitCount = false) const;
- QString uniqueSortKey(void) const;
+ TQString uniqueSortKey(void) const;
/**
* This module implements an algorithm used by P.J. Weinberger
@@ -293,13 +293,13 @@ public:
* @param h initial hash value (default 0)
* @return non-unique hash value of the text @p txt
*/
- static unsigned long hash(const QString& txt, unsigned long h = 0);
+ static unsigned long hash(const TQString& txt, unsigned long h = 0);
private:
/**
* This method returns the next id to be used for a split
*/
- const QString nextSplitID(void);
+ const TQString nextSplitID(void);
private:
static const int SPLIT_ID_SIZE = 4;
@@ -308,22 +308,22 @@ private:
* This member contains the date when the transaction was entered
* into the engine
*/
- QDate m_entryDate;
+ TQDate m_entryDate;
/**
* This member contains the date the transaction was posted
*/
- QDate m_postDate;
+ TQDate m_postDate;
/**
* This member keeps the memo text associated with this transaction
*/
- QString m_memo;
+ TQString m_memo;
/**
* This member contains the splits for this transaction
*/
- QValueList<MyMoneySplit> m_splits;
+ TQValueList<MyMoneySplit> m_splits;
/**
* This member keeps the unique numbers of splits within this
@@ -335,7 +335,7 @@ private:
/**
* This member keeps the base commodity (e.g. currency) for this transaction
*/
- QString m_commodity;
+ TQString m_commodity;
/**
* This member keeps the bank's unique ID for the transaction, so we can
@@ -343,7 +343,7 @@ private:
*
* Note this is now deprecated! Bank ID's should be set on splits, not transactions.
*/
- QString m_bankID;
+ TQString m_bankID;
/** constants for unique sort key */
static const int YEAR_SIZE = 4;
@@ -43,7 +43,7 @@
* This class represents a transaction within the MyMoneyEngine. A transaction
* contains none, one or more splits of type MyMoneySplit. They are stored in
- * a QValueList<MyMoneySplit> within this object. A transaction containing only
+ * a TQValueList<MyMoneySplit> within this object. A transaction containing only
* a single split with an amount not equal to 0 is an unbalanced transaction. It
* is tolerated by the engine, but in general not a good idea as it is financially
@@ -52,35 +52,35 @@ class KMYMONEY_EXPORT MyMoneyTransaction : public MyMoneyObject, public MyMoneyK
const MyMoneyTransaction& transaction);
/**
- * @param node reference to QDomNode
- * @param forceId see MyMoneyObject(const QDomElement&, const bool)
+ * @param node reference to TQDomNode
+ * @param forceId see MyMoneyObject(const TQDomElement&, const bool)
*/
@@ -237,11 +237,11 @@ public:
* was entered.
*
- * @return QString with ID of the first split of transactions
+ * @return TQString with ID of the first split of transactions
*/